.. kollacli documentation master file, created by
   sphinx-quickstart on Thu Mar 17 18:17:04 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to kolla-cli's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 2

   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

